"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const jenkins_cli_1 = require("./jenkins-cli");
const utils_1 = require("./utils");
const inquirer_1 = require("./inquirer");
const config_1 = require("./config");
const opn = require("opn");
exports.run = (options) => __awaiter(void 0, void 0, void 0, function* () {
    const jk = new jenkins_cli_1.JenkinsCli(options);
    try {
        // get the job list
        const jobs = yield jk.getJobs();
        // Reade the user selected job
        const selectJob = yield inquirer_1.singleSelection([config_1.LAST_KEY].concat(jobs), `Select your jenkins job (${jobs.length})`);
        // get all parameters for the job
        const parametersInfo = yield jk.getParameters(selectJob);
        let parameters = {};
        // Reade the user selected parameters
        const parameterMsg = "Select your parameters: ";
        for (const k of parametersInfo) {
            switch (k.type) {
                case jenkins_cli_1.ParameterType.git:
                case jenkins_cli_1.ParameterType.radio:
                    parameters[k.key] = yield inquirer_1.singleSelection(k.value, parameterMsg + k.description);
                    break;
                case jenkins_cli_1.ParameterType.checkbox:
                    parameters[k.key] = yield inquirer_1.multipleSelection(k.value, parameterMsg + k.description);
                    break;
            }
        }
        utils_1.printInfo(`Building job: ${selectJob} `);
        const buildInfo = yield jk.build(selectJob, parameters);
        utils_1.alert(`Jenkins job: ${selectJob}`, "Click for details.", () => {
            opn(buildInfo.url);
        });
    }
    catch (err) {
        utils_1.printError(err);
    }
});
//# sourceMappingURL=index.js.map